/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderRefund;
import org.springblade.modules.finance.vo.OrderRefundVO;
import org.springblade.modules.finance.service.IOrderRefundService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 退款信息 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/orderrefund")
@Api(value = "退款信息", tags = "退款信息接口")
public class OrderRefundController extends BladeController {

	private final IOrderRefundService orderRefundService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderRefund")
	public R<OrderRefund> detail(OrderRefund orderRefund) {
		OrderRefund detail = orderRefundService.getOne(Condition.getQueryWrapper(orderRefund));
		return R.data(detail);
	}

	/**
	 * 分页 退款信息
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderRefund")
	public R<IPage<OrderRefund>> list(OrderRefund orderRefund, Query query) {
		IPage<OrderRefund> pages = orderRefundService.page(Condition.getPage(query), Condition.getQueryWrapper(orderRefund));
		return R.data(pages);
	}

	/**
	 * 自定义分页 退款信息
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderRefund")
	public R<IPage<OrderRefundVO>> page(OrderRefundVO orderRefund, Query query) {
		IPage<OrderRefundVO> pages = orderRefundService.selectOrderRefundPage(Condition.getPage(query), orderRefund);
		return R.data(pages);
	}

	/**
	 * 新增 退款信息
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderRefund")
	public R save(@Valid @RequestBody OrderRefund orderRefund) {
		return R.status(orderRefundService.save(orderRefund));
	}

	/**
	 * 修改 退款信息
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderRefund")
	public R update(@Valid @RequestBody OrderRefund orderRefund) {
		return R.status(orderRefundService.updateById(orderRefund));
	}

	/**
	 * 新增或修改 退款信息
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderRefund")
	public R submit(@Valid @RequestBody OrderRefund orderRefund) {
		return R.status(orderRefundService.saveOrUpdate(orderRefund));
	}

	
	/**
	 * 删除 退款信息
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderRefundService.removeByIds(Func.toLongList(ids)));
	}

	
}
