/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 订单物流表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_order_express")
@ApiModel(value = "OrderExpress对象", description = "订单物流表")
public class OrderExpress implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long id;
	/**
	 * 订单ID
	 */
	@ApiModelProperty(value = "订单ID")
	private Long orderId;
	/**
	 * 订单商品ID列表
	 */
	@ApiModelProperty(value = "订单商品ID列表")
	private Long orderGoodsId;
	/**
	 * 发货时间
	 */
	@ApiModelProperty(value = "发货时间")
	private LocalDateTime deliveryTime;
	/**
	 * 发货方式,1：使用物流 0：未用物流
	 */
	@ApiModelProperty(value = "发货方式,1：使用物流 0：未用物流")
	private Boolean isExpress;
	/**
	 * 快递商ID
	 */
	@ApiModelProperty(value = "快递商ID")
	private Long expressId;
	/**
	 * 快递号
	 */
	@ApiModelProperty(value = "快递号")
	private String expressNo;
	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private LocalDateTime createTime;
	/**
	 * 发货类型标志,0:手工发货 1：导入excel发货
	 */
	@ApiModelProperty(value = "发货类型标志,0:手工发货 1：导入excel发货")
	private Boolean deliverType;


}
