/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.models.auth.In;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 商品寄售表实体类
 *
 * @author BladeX
 * @since 2022年4月9日15:03:14
 */
@Data
@TableName("t_platform_authorization")
@ApiModel(value = "PlatformAuthorization", description = "场次授权付款表")
public class PlatformAuthorization implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long id;

	/**
	 * 订单ID
	 */
	@ApiModelProperty(value = "订单ID")
	private String orderNo;

	/**
	 * 批次ID
	 */
	@ApiModelProperty(value = "批次ID")
	private Long consignConfigId;

	/**
	 * 授权数量
	 */
	@ApiModelProperty(value = "授权数量")
	private Integer totalNum;

	/**
	 * 授权号
	 */
	@ApiModelProperty(value = "授权号")
	private String authNo;

	/**
	 * 授权金额
	 */
	@ApiModelProperty(value = "授权金额")
	private BigDecimal authPrice;

	/**
	 * 授权状态
	 */
	@ApiModelProperty(value = "授权状态：0、未授权，1、已授权，2已解冻")
	private Integer state;

	/**
	 * 用户创建id
	 */
	@ApiModelProperty(value = "用户创建id")
	private Long createUserId;

	/**
	 * 结束时间
	 */
	@ApiModelProperty(value = "结束时间")
	private Date endTime;

	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private Date createTime;

	@TableLogic
	@ApiModelProperty(value = "删除标识   0正常  1逻辑删除")
	private Integer isDeleted;
}
