/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.vo.ConsignVO;
import org.springblade.modules.shopping.mapper.ConsignMapper;
import org.springblade.modules.shopping.service.IConsignService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.shopping.wrapper.ConsignWrapper;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.List;

/**
 * 商品寄售表 服务实现类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Service
public class ConsignServiceImpl extends ServiceImpl<ConsignMapper, Consign> implements IConsignService {

	@Override
	public IPage<ConsignVO> selectConsignPage(IPage<ConsignVO> page, ConsignVO consign) {
		return page.setRecords(baseMapper.selectConsignPage(page, consign));
	}

	@Override
	public List<ConsignVO> selectConsignList(Long consignConfigId) {
		//String startTime = DateUtil.format(DateUtil.now(), DateUtil.PATTERN_DATETIME);
		List<Consign> list = baseMapper.selectList(Wrappers.<Consign>lambdaQuery()
			.eq(Consign::getIsSale,2)
			.eq(Consign::getConsignFor,1)
			.gt(Consign::getNowStock,0)
			.eq(Consign::getConsignConfigId, consignConfigId)
			//.last(" and to_days(start_time) = to_days(now())")
		);
		return ConsignWrapper.build().listVO(list);
	}

	@Override
	public Consign queryConsign(Long consignConfigId, Long userId) {
		return baseMapper.queryConsign(consignConfigId,userId);
	}

	@Override
	public Consign randomConsign(Long consignConfigId, Long userId) {
		return baseMapper.randomConsign(consignConfigId,userId);
	}

}
