/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.springblade.modules.shopping.entity.SpecCats;
import org.springblade.modules.shopping.entity.SpecItems;
import org.springblade.modules.shopping.vo.SpecCatsVO;
import org.springblade.modules.shopping.mapper.SpecCatsMapper;
import org.springblade.modules.shopping.service.ISpecCatsService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.shopping.wrapper.SpecCatsWrapper;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.ArrayList;
import java.util.List;

/**
 * 规格分类表 服务实现类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Service
public class SpecCatsServiceImpl extends ServiceImpl<SpecCatsMapper, SpecCats> implements ISpecCatsService {

	@Override
	public IPage<SpecCatsVO> selectSpecCatsPage(IPage<SpecCatsVO> page, SpecCatsVO specCats) {
		return page.setRecords(baseMapper.selectSpecCatsPage(page, specCats));
	}

	@Override
	public List<SpecCatsVO> selectSpecItems(Long goodsId, Long catId) {
		List<SpecCatsVO> voList = new ArrayList<>();
		List<SpecCats> list = baseMapper.selectList(Wrappers.<SpecCats>lambdaQuery().eq(SpecCats::getCatId, catId));
		list.forEach(item -> {
			SpecCatsVO specCatsVO = SpecCatsWrapper.build().entityVO(item);
			SpecItems specItems = new SpecItems();
			List<SpecItems> specItemsList = specItems.selectList(Wrappers.<SpecItems>lambdaQuery()
				.eq(SpecItems::getSpecCatId, item.getSpecCatId())
				.eq(SpecItems::getGoodsId, goodsId));
			specCatsVO.setSpecItems(specItemsList);
			voList.add(specCatsVO);
		});
		return voList;
	}

}
