/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.wrapper;

import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.core.tool.utils.SpringUtil;
import org.springblade.modules.shopping.entity.Attributes;
import org.springblade.modules.shopping.entity.GoodsAttributes;
import org.springblade.modules.shopping.service.IAttributesService;
import org.springblade.modules.shopping.vo.GoodsAttributesVO;

import java.util.Objects;

/**
 * 包装类,返回视图层所需的字段
 *
 * @author Chill
 */
public class GoodsAttributesWrapper extends BaseEntityWrapper<GoodsAttributes, GoodsAttributesVO> {

	public static GoodsAttributesWrapper build() {
		return new GoodsAttributesWrapper();
	}

	public static IAttributesService attributesService;

	static {
		attributesService = SpringUtil.getBean(IAttributesService.class);
	}

	@Override
	public GoodsAttributesVO entityVO(GoodsAttributes entity) {
		GoodsAttributesVO vo = Objects.requireNonNull(BeanUtil.copy(entity, GoodsAttributesVO.class));
		Attributes attributes = attributesService.getById(entity.getAttrId());
		if (attributes != null){
			vo.setFieldName(attributes.getFieldName());
			vo.setTitle(attributes.getTitle());
			vo.setUnit(attributes.getUnit());
		}
		return vo;
	}

}
